==> apo_0.2.4.tar.gz: apoinstall/install/index.php <==
<?php
	$phpversion = phpversion();
	if($phpversion < "5"){
		echo "You need PHP 5";
		exit;
	}
	include_once "../config/import.php";
	import("com.neolao.database.MySQLManager");
	import("com.neolao.system.FolderUtils");
	// +------------------------------------------------------------------+
	// |                 Formulaire d'installation envoyé                 |
	// +------------------------------------------------------------------+
	if(!empty($_POST["submit"])){
		$stopInstall = false;
		$errors = "";
		$success = "";
		$infoPHP = pathinfo(__FILE__);
		$php5extension = $infoPHP["extension"];
		
		// Vérification des informations BDD
		if(empty($_POST["bddhost"])){
			$stopInstall = true;
			$errors .= "<li>Il manque l'adresse du serveur de base de données</li>";
		}
		// Vérification des informations BDD
		if(empty($_POST["bddname"])){
			$stopInstall = true;
			$errors .= "<li>Il manque le nom de la base de données</li>";
		}
		// Vérification des informations BDD
		if(empty($_POST["bddlogin"])){
			$stopInstall = true;
			$errors .= "<li>Il manque l'identifiant de la base de données</li>";
		}
		// Vérification des informations BDD
		if(empty($_POST["bddpassword"])){
			$stopInstall = true;
			$errors .= "<li>Il manque le mot de passe de la base de données</li>";
		}
		// Vérification des informations APO
		if(empty($_POST["apourl"])){
			$stopInstall = true;
			$errors .= "<li>Il manque l'URL du site</li>";
		}
		// Vérification des informations Admin
		if(empty($_POST["adminname"])){
			$stopInstall = true;
			$errors .= "<li>Il manque le nom de l'administrateur</li>";
		}
		// Vérification des informations Admin
		if(empty($_POST["adminpass"]) && $_POST["adminpass"] == $_POST["adminpass2"]){
			$stopInstall = true;
			$errors .= "<li>Il manque le mot de passe de l'administrateur</li>";
		}
		
		// Tout est ok
		
		// Tentative de connexion à la base de données
		if(!$stopInstall){
			$myBDD = new MySQLManager($_POST["bddhost"], $_POST["bddname"], $_POST["bddlogin"], $_POST["bddpassword"]);
			if($myBDD->connected === false){
				// Echec lors de la connexion à la base
				$stopInstall = true;
				$errors .= "<li>Echec lors de la connexion à la base</li>";
			}
		}
		// Récupération de la requête
		if(!$stopInstall){
			$request = @file_get_contents("./mysql_install.sql");
			if($request === false){
				// Echec lors de la récupération de la requête
				$stopInstall = true;
				$errors .= "<li>Echec lors de la récupération de la requête</li>";
			}
		}
		// Exécution de la requête
		if(!$stopInstall){
			$request = str_replace("apo_", $_POST["bddtbprefix"], $request);
			$requestAll = explode(";", $request);
			for($i=0; $i<count($requestAll); $i++){
				if(!empty($requestAll[$i])){
					$result = $myBDD->query($requestAll[$i]);
					if($result === false){
						// Erreur pendant la requête
						$stopInstall = true;
						$errors .= "<li>".mysql_error()."</li>";
					}
				}
			}
		}
		// Requête réussie, les tables sont installées
		if(!$stopInstall){
			$success .= "<li>Les tables ont été créées dans la base de données</li>";
		}
		// On tente de créer le fichier config.ini
		if(!$stopInstall){
			$configFile = @fopen("../config/config.ini", "w");
			if($configFile === false){
				// Problème de droit d'écriture
				$stopInstall = true;
				$errors .= "<li>Erreur lors de la création du fichier config.ini</li>";
			}
		}
		// Récupération du template de config.ini
		if(!$stopInstall){
			$configContent = @file_get_contents("../config/config.ini.txt");
			if($configContent === false){
				// Impossible de lire config.ini.txt
				$stopInstall = true;
				$errors .= "<li>Impossible de lire config.ini.txt</li>";
			}
		}
		// Le fichier config.ini est prêt à être rempli
		if(!$stopInstall){
			$configContent = str_replace("{{dbprefix}}", $_POST["bddtbprefix"], $configContent);
			$configContent = str_replace("{{webroot}}", $_POST["apourl"], $configContent);
			$configContent = str_replace("{{updateurl}}", "http://www.neolao.com/apoupdate", $configContent);
			$configContent = str_replace("{{phpextension}}", $_POST["phpextension"], $configContent);
			$configContent = str_replace("{{themedefault}}", "default", $configContent);
			if(fwrite($configFile, $configContent) === false){
				// Impossible d'écrire dans config.ini
				$stopInstall = true;
				$errors .= "<li>Impossible d'écrire dans config.ini</li>";
			}else{
				// Création du fichier config.ini réussie
				$success .= "<li>Création du fichier config.ini réussie</li>";
			}
		}
		// On tente de créer le fichier connect.php
		if(!$stopInstall){
			$connectFile = @fopen("../config/connect.php", "w");
			if($connectFile === false){
				// Problème de droit d'écriture
				$stopInstall = true;
				$errors .= "<li>Erreur lors de la création du fichier connect.php</li>";
			}
		}
		// Récupération du template de connect.php
		if(!$stopInstall){
			$connectContent = @file_get_contents("../config/connect.php.txt");
			if($connectContent === false){
				// Impossible de lire connect.php.txt
				$stopInstall = true;
				$errors .= "<li>Impossible de lire connect.php.txt</li>";
			}
		}
		// Le fichier connect.php est prêt à être rempli
		if(!$stopInstall){
			$connectContent = str_replace("{{bddhost}}", $_POST["bddhost"], $connectContent);
			$connectContent = str_replace("{{bddname}}", $_POST["bddname"], $connectContent);
			$connectContent = str_replace("{{bddlogin}}", $_POST["bddlogin"], $connectContent);
			$connectContent = str_replace("{{bddpassword}}", $_POST["bddpassword"], $connectContent);
			if(fwrite($connectFile, $connectContent) === false){
				// Impossible d'écrire dans connect.php
				$stopInstall = true;
				$errors .= "<li>Impossible d'écrire dans connect.php</li>";
			}else{
				// Création du fichier connect.php réussie
				$success .= "<li>Création du fichier connect.php réussie</li>";
			}
			fclose($connectFile);
		}
		// Renommer les fichiers php5
		if(!$stopInstall){
			if($php5extension != "php"){
				if(@rename("./../index.php", "./../index.".$php5extension) === false){
					// Erreur de renommage
					$stopInstall = true;
					$errors .= "<li>Impossible de renommer index.php en index.".$php5extension.", permission non accordée. Vérifiez les droits du fichier et du dossier.</li>";
				}else{
					$success .= "<li>Le fichier index.php a été renommé en index.".$php5extension."</li>";
				}
				if(@rename("./../bookmarks.php", "./../bookmarks.".$php5extension) === false){
					// Erreur de renommage
					$stopInstall = true;
					$errors .= "<li>Impossible de renommer bookmarks.php en bookmarks.".$php5extension.", permission non accordée. Vérifiez les droits du fichier et du dossier.</li>";
				}else{
					$success .= "<li>Le fichier bookmarks.php a été renommé en bookmarks.".$php5extension."</li>";
				}
				if(@rename("./../rss.php", "./../rss.".$php5extension) === false){
					// Erreur de renommage
					$stopInstall = true;
					$errors .= "<li>Impossible de renommer rss.php en rss.".$php5extension.", permission non accordée. Vérifiez les droits du fichier et du dossier.</li>";
				}else{
					$success .= "<li>Le fichier rss.php a été renommé en rss.".$php5extension."</li>";
				}
			}
		}
		// On tente de créer le fichier .htaccess
		if(!$stopInstall){
			$htaccessFile = @fopen("../.htaccess", "w");
			if($htaccessFile === false){
				// Problème de droit d'écriture
				$stopInstall = true;
				$errors .= "<li>Erreur lors de la création du fichier .htaccess</li>";
			}
		}
		// Récupération du template de connect.php
		if(!$stopInstall){
			$htaccessContent = @file_get_contents("../htaccess.txt");
			if($htaccessContent === false){
				// Impossible de lire htaccess.txt
				$stopInstall = true;
				$errors .= "<li>Impossible de lire htaccess.txt</li>";
			}
		}
		// Le fichier .htaccess est prêt à être rempli
		if(!$stopInstall){
			$webroot = $_SERVER["PHP_SELF"];
			$installFile = "/install/index.php";
			$webroot = substr($webroot, 0, -strlen($installFile));
			$htaccessContent = str_replace("{{webroot}}", $webroot, $htaccessContent);
			$htaccessContent = str_replace("{{ext}}", $php5extension, $htaccessContent);
			if(fwrite($htaccessFile, $htaccessContent) === false){
				// Impossible d'écrire dans .htaccess
				$stopInstall = true;
				$errors .= "<li>Impossible d'écrire dans .htaccess</li>";
			}else{
				// Création du fichier .htaccess réussie
				$success .= "<li>Création du fichier .htaccess à la racine</li>";
			}
			fclose($htaccessFile);
		}
		// Création du compte administrateur
		if(!$stopInstall){
			$result = $myBDD->insert($_POST["bddtbprefix"]."users", array("createDate", "name", "password", "admin"), array("'".gmdate("Y-m-d H:i:s")."'", "'".$_POST["adminname"]."'", "'".md5($_POST["adminpass"])."'", "'true'"));
			if($result === false){
				$stopInstall = true;
				$errors .= "<li>Impossible de créer le compte administrateur</li>";
			}else{
				$success .= "<li>Le compte administrateur a bien été créé (identifiant \"".$_POST["adminname"]."\" et mot de passe \"".$_POST["adminpass"]."\")</li>";
			}
		}
		// On efface le répertoire d'installation
		if(!$stopInstall){
			$result = @FolderUtils::delete("./");
			if($result === false){
				$stopInstall = true;
				$errors .= "<li>Impossible d'effacer le dossier d'installation, veuillez le supprimer pour une raison de sécurité.</li>";
			}else{
				$success .= "<li>Le dossier d'installation a été supprimé</li>";
			}
		}
		
		// l'installation est réussie
		if(!$stopInstall){
			$success .= "<li>Le site a bien été installé, vous pouvez y accéder sur ce lien : <a href=\"".$_POST["apourl"]."\">".$_POST["apourl"]."</a></li>";
		}
	}
	
	// +------------------------------------------------------------------+
	// |                      Détection de la langue                      |
	// +------------------------------------------------------------------+
    $langs_accept = explode(",", $_SERVER["HTTP_ACCEPT_LANGUAGE"]);
	$langs = array("fr");
	$langs_intersect = array_intersect ($langs_accept, $langs);
	if(count($langs_intersect) > 0){
		$lang = $langs_intersect[0];
	}else{
		$lang = "fr";
	}
	
	// +------------------------------------------------------------------+
	// |                             En-tête                              |
	// +------------------------------------------------------------------+
	$accept_xml = !empty($_SERVER['HTTP_ACCEPT']) && strpos($_SERVER['HTTP_ACCEPT'],'application/xhtml+xml') !== false;
	if ($accept_xml) {
		header('Content-Type: application/xhtml+xml');
		echo '<?xml version="1.0" encoding="utf-8"?>'."\n";
	} else {
		header('Content-Type: text/html; charset=utf-8');
	}
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $lang; ?>" lang="<?php echo $lang; ?>">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<meta http-equiv="Content-Style-Type" content="text/css" />
		<link rel="stylesheet" type="text/css" href="../themes/default/style.css" />
		<title>APO - Installation</title>
	</head>
	<body>
		<div id="header">
			<div class="banner"></div>
		</div>	
		<div id="content" class="install">
			<h1>Installation de APO</h1>
			<?php if(empty($success) && empty($errors)){ ?>
			<form action="<?php echo basename(__FILE__); ?>" method="post">
				<fieldset>
					<legend>Base de données</legend>
					<p>APO a été testé sur MySQL 4.1.11</p>
					<ul>
						<li><label for="bddhost">Serveur</label><input type="text" id="bddhost" name="bddhost" value="" /></li>
						<li><label for="bddname">Nom</label><input type="text" id="bddname" name="bddname" value="" /></li>
						<li><label for="bddlogin">Identifiant</label><input type="text" id="bddlogin" name="bddlogin" value="" /></li>
						<li><label for="bddpassword">Mot de passe</label><input type="password" id="bddpassword" name="bddpassword" value="" /></li>
						<li><label for="bddtbprefix">Préfixe des tables</label><input type="text" id="bddtbprefix" name="bddtbprefix" value="apo_" /></li>
					</ul>
				</fieldset>
				<fieldset>
					<legend>Compte administrateur</legend>
					<p>Pour une simplification de la gestion du site et des utilisateurs, un compte administrateur doit être créé.</p>
					<ul>
						<li><label for="adminname">Identifiant</label><input type="text" id="adminname" name="adminname" value="admin" /></li>
						<li><label for="adminpass">Mot de passe</label><input type="password" id="adminpass" name="adminpass" value="" /></li>
						<li><label for="adminpass2">Retapez le mot de passe</label><input type="password" id="adminpass2" name="adminpass2" value="" /></li>
					</ul>
				</fieldset>
				<fieldset>
					<legend>APO</legend>
					<ul>
						<li><label for="apourl">URL du site</label><input type="text" id="apourl" name="apourl" value="http://localhost/apo" /></li>
					</ul>
				</fieldset>
				<p>
					<input type="submit" name="submit" value="Installer" />
				</p>
			</form>
			<?php }else if($stopInstall){ ?>
			<p>Erreur lors de l'installation.</p>
			<ul><?php echo $success.$errors; ?></ul>
			<?php }else{ ?>
			<p>Installation réussie.</p>
			<ul><?php echo $success.$errors; ?></ul>
			<?php } ?>
		</div>
	</body>
</html>

==> apo_0.2.9.tar.gz: apoinstall/install/index.php <==
<?php
	$phpversion = phpversion();
	if($phpversion < "5"){
		echo "You need PHP 5";
		exit;
	}
	include_once "../config/import.php";
	import("com.neolao.database.MySQLManager");
	import("com.neolao.system.FolderUtils");
	// +------------------------------------------------------------------+
	// |                 Formulaire d'installation envoyé                 |
	// +------------------------------------------------------------------+
	if(!empty($_POST["submit"])){
		$stopInstall = false;
		$errors = "";
		$success = "";
		$infoPHP = pathinfo(__FILE__);
		$php5extension = $infoPHP["extension"];
		
		// Vérification des informations BDD
		if(empty($_POST["bddhost"])){
			$stopInstall = true;
			$errors .= "<li>Il manque l'adresse du serveur de base de données</li>";
		}
		// Vérification des informations BDD
		if(empty($_POST["bddname"])){
			$stopInstall = true;
			$errors .= "<li>Il manque le nom de la base de données</li>";
		}
		// Vérification des informations BDD
		if(empty($_POST["bddlogin"])){
			$stopInstall = true;
			$errors .= "<li>Il manque l'identifiant de la base de données</li>";
		}
		// Vérification des informations BDD
		if(empty($_POST["bddpassword"])){
			$stopInstall = true;
			$errors .= "<li>Il manque le mot de passe de la base de données</li>";
		}
		// Vérification des informations APO
		if(empty($_POST["apourl"])){
			$stopInstall = true;
			$errors .= "<li>Il manque l'URL du site</li>";
		}
		// Vérification des informations Admin
		if(empty($_POST["adminname"])){
			$stopInstall = true;
			$errors .= "<li>Il manque le nom de l'administrateur</li>";
		}
		// Vérification des informations Admin
		if(empty($_POST["adminpass"]) && $_POST["adminpass"] == $_POST["adminpass2"]){
			$stopInstall = true;
			$errors .= "<li>Il manque le mot de passe de l'administrateur</li>";
		}
		
		// Tout est ok
		
		// Tentative de connexion à la base de données
		if(!$stopInstall){
			$myBDD = new MySQLManager($_POST["bddhost"], $_POST["bddname"], $_POST["bddlogin"], $_POST["bddpassword"]);
			if($myBDD->connected === false){
				// Echec lors de la connexion à la base
				$stopInstall = true;
				$errors .= "<li>Echec lors de la connexion à la base</li>";
			}
		}
		// Récupération de la requête
		if(!$stopInstall){
			$request = @file_get_contents("./mysql_install.sql");
			if($request === false){
				// Echec lors de la récupération de la requête
				$stopInstall = true;
				$errors .= "<li>Echec lors de la récupération de la requête</li>";
			}
		}
		// Exécution de la requête
		if(!$stopInstall){
			$request = str_replace("apo_", $_POST["bddtbprefix"], $request);
			$requestAll = explode(";", $request);
			for($i=0; $i<count($requestAll); $i++){
				if(!empty($requestAll[$i])){
					$result = $myBDD->query($requestAll[$i]);
					if($result === false){
						// Erreur pendant la requête
						$stopInstall = true;
						$errors .= "<li>".mysql_error()."</li>";
					}
				}
			}
		}
		// Requête réussie, les tables sont installées
		if(!$stopInstall){
			$success .= "<li>Les tables ont été créées dans la base de données</li>";
		}
		// On tente de créer le fichier config.ini
		if(!$stopInstall){
			$configFile = @fopen("../config/config.ini", "w");
			if($configFile === false){
				// Problème de droit d'écriture
				$stopInstall = true;
				$errors .= "<li>Erreur lors de la création du fichier config.ini</li>";
			}
		}
		// Récupération du template de config.ini
		if(!$stopInstall){
			$configContent = @file_get_contents("../config/config.ini.txt");
			if($configContent === false){
				// Impossible de lire config.ini.txt
				$stopInstall = true;
				$errors .= "<li>Impossible de lire config.ini.txt</li>";
			}
		}
		// Le fichier config.ini est prêt à être rempli
		if(!$stopInstall){
			$configContent = str_replace("{{dbprefix}}", $_POST["bddtbprefix"], $configContent);
			$configContent = str_replace("{{webroot}}", $_POST["apourl"], $configContent);
			$configContent = str_replace("{{updateurl}}", "http://www.neolao.com/apoupdate", $configContent);
			$configContent = str_replace("{{phpextension}}", $php5extension, $configContent);
			$configContent = str_replace("{{themedefault}}", "default", $configContent);
			if(fwrite($configFile, $configContent) === false){
				// Impossible d'écrire dans config.ini
				$stopInstall = true;
				$errors .= "<li>Impossible d'écrire dans config.ini</li>";
			}else{
				// Création du fichier config.ini réussie
				$success .= "<li>Création du fichier config.ini réussie</li>";
			}
		}
		// On tente de créer le fichier connect.php
		if(!$stopInstall){
			$connectFile = @fopen("../config/connect.php", "w");
			if($connectFile === false){
				// Problème de droit d'écriture
				$stopInstall = true;
				$errors .= "<li>Erreur lors de la création du fichier connect.php</li>";
			}
		}
		// Récupération du template de connect.php
		if(!$stopInstall){
			$connectContent = @file_get_contents("../config/connect.php.txt");
			if($connectContent === false){
				// Impossible de lire connect.php.txt
				$stopInstall = true;
				$errors .= "<li>Impossible de lire connect.php.txt</li>";
			}
		}
		// Le fichier connect.php est prêt à être rempli
		if(!$stopInstall){
			$connectContent = str_replace("{{bddhost}}", $_POST["bddhost"], $connectContent);
			$connectContent = str_replace("{{bddname}}", $_POST["bddname"], $connectContent);
			$connectContent = str_replace("{{bddlogin}}", $_POST["bddlogin"], $connectContent);
			$connectContent = str_replace("{{bddpassword}}", $_POST["bddpassword"], $connectContent);
			if(fwrite($connectFile, $connectContent) === false){
				// Impossible d'écrire dans connect.php
				$stopInstall = true;
				$errors .= "<li>Impossible d'écrire dans connect.php</li>";
			}else{
				// Création du fichier connect.php réussie
				$success .= "<li>Création du fichier connect.php réussie</li>";
			}
			fclose($connectFile);
		}
		// Renommer les fichiers php5
		if(!$stopInstall){
			if($php5extension != "php"){
				if(@rename("./../index.php", "./../index.".$php5extension) === false){
					// Erreur de renommage
					$stopInstall = true;
					$errors .= "<li>Impossible de renommer index.php en index.".$php5extension.", permission non accordée. Vérifiez les droits du fichier et du dossier.</li>";
				}else{
					$success .= "<li>Le fichier index.php a été renommé en index.".$php5extension."</li>";
				}
				if(@rename("./../bookmarks.php", "./../bookmarks.".$php5extension) === false){
					// Erreur de renommage
					$stopInstall = true;
					$errors .= "<li>Impossible de renommer bookmarks.php en bookmarks.".$php5extension.", permission non accordée. Vérifiez les droits du fichier et du dossier.</li>";
				}else{
					$success .= "<li>Le fichier bookmarks.php a été renommé en bookmarks.".$php5extension."</li>";
				}
				if(@rename("./../rss.php", "./../rss.".$php5extension) === false){
					// Erreur de renommage
					$stopInstall = true;
					$errors .= "<li>Impossible de renommer rss.php en rss.".$php5extension.", permission non accordée. Vérifiez les droits du fichier et du dossier.</li>";
				}else{
					$success .= "<li>Le fichier rss.php a été renommé en rss.".$php5extension."</li>";
				}
			}
		}
		// On tente de créer le fichier .htaccess
		if(!$stopInstall){
			$htaccessFile = @fopen("../.htaccess", "w");
			if($htaccessFile === false){
				// Problème de droit d'écriture
				$stopInstall = true;
				$errors .= "<li>Erreur lors de la création du fichier .htaccess</li>";
			}
		}
		// Récupération du template de connect.php
		if(!$stopInstall){
			$htaccessContent = @file_get_contents("../htaccess.txt");
			if($htaccessContent === false){
				// Impossible de lire htaccess.txt
				$stopInstall = true;
				$errors .= "<li>Impossible de lire htaccess.txt</li>";
			}
		}
		// Le fichier .htaccess est prêt à être rempli
		if(!$stopInstall){
			$webroot = $_SERVER["PHP_SELF"];
			$installFile = "/install/index.php";
			$webroot = substr($webroot, 0, -strlen($installFile));
			$htaccessContent = str_replace("{{webroot}}", $webroot, $htaccessContent);
			$htaccessContent = str_replace("{{ext}}", $php5extension, $htaccessContent);
			if(fwrite($htaccessFile, $htaccessContent) === false){
				// Impossible d'écrire dans .htaccess
				$stopInstall = true;
				$errors .= "<li>Impossible d'écrire dans .htaccess</li>";
			}else{
				// Création du fichier .htaccess réussie
				$success .= "<li>Création du fichier .htaccess à la racine</li>";
			}
			fclose($htaccessFile);
		}
		// Création du compte administrateur
		if(!$stopInstall){
			$result = $myBDD->insert($_POST["bddtbprefix"]."users", array("createDate", "name", "password", "admin"), array("'".gmdate("Y-m-d H:i:s")."'", "'".$_POST["adminname"]."'", "'".md5($_POST["adminpass"])."'", "'true'"));
			if($result === false){
				$stopInstall = true;
				$errors .= "<li>Impossible de créer le compte administrateur</li>";
			}else{
				$success .= "<li>Le compte administrateur a bien été créé (identifiant \"".$_POST["adminname"]."\" et mot de passe \"".$_POST["adminpass"]."\")</li>";
			}
		}
		// On efface le répertoire d'installation
		if(!$stopInstall){
			$result = @FolderUtils::delete("./");
			if($result === false){
				$stopInstall = true;
				$errors .= "<li>Impossible d'effacer le dossier d'installation, veuillez le supprimer pour une raison de sécurité.</li>";
			}else{
				$success .= "<li>Le dossier d'installation a été supprimé</li>";
			}
		}
		
		// l'installation est réussie
		if(!$stopInstall){
			$success .= "<li>Le site a bien été installé, vous pouvez y accéder sur ce lien : <a href=\"".$_POST["apourl"]."\">".$_POST["apourl"]."</a></li>";
		}
	}
	
	// +------------------------------------------------------------------+
	// |                      Détection de la langue                      |
	// +------------------------------------------------------------------+
    $langs_accept = explode(",", $_SERVER["HTTP_ACCEPT_LANGUAGE"]);
	$langs = array("fr");
	$langs_intersect = array_intersect ($langs_accept, $langs);
	if(count($langs_intersect) > 0){
		$lang = $langs_intersect[0];
	}else{
		$lang = "fr";
	}
	
	// +------------------------------------------------------------------+
	// |                             En-tête                              |
	// +------------------------------------------------------------------+
	$accept_xml = !empty($_SERVER['HTTP_ACCEPT']) && strpos($_SERVER['HTTP_ACCEPT'],'application/xhtml+xml') !== false;
	if ($accept_xml) {
		header('Content-Type: application/xhtml+xml');
		echo '<?xml version="1.0" encoding="utf-8"?>'."\n";
	} else {
		header('Content-Type: text/html; charset=utf-8');
	}
?><!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php echo $lang; ?>" lang="<?php echo $lang; ?>">
	<head>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
		<meta http-equiv="Content-Style-Type" content="text/css" />
		<link rel="stylesheet" type="text/css" href="../themes/default/style.css" />
		<title>APO - Installation</title>
	</head>
	<body>
		<div id="header">
			<div class="banner"></div>
		</div>	
		<div id="content" class="install">
			<h1>Installation de APO</h1>
			<?php if(empty($success) && empty($errors)){ ?>
			<form action="<?php echo basename(__FILE__); ?>" method="post">
				<fieldset>
					<legend>Base de données</legend>
					<p>APO a été testé sur MySQL 4.1.11</p>
					<ul>
						<li><label for="bddhost">Serveur</label><input type="text" id="bddhost" name="bddhost" value="" /></li>
						<li><label for="bddname">Nom</label><input type="text" id="bddname" name="bddname" value="" /></li>
						<li><label for="bddlogin">Identifiant</label><input type="text" id="bddlogin" name="bddlogin" value="" /></li>
						<li><label for="bddpassword">Mot de passe</label><input type="password" id="bddpassword" name="bddpassword" value="" /></li>
						<li><label for="bddtbprefix">Préfixe des tables</label><input type="text" id="bddtbprefix" name="bddtbprefix" value="apo_" /></li>
					</ul>
				</fieldset>
				<fieldset>
					<legend>Compte administrateur</legend>
					<p>Pour une simplification de la gestion du site et des utilisateurs, un compte administrateur doit être créé.</p>
					<ul>
						<li><label for="adminname">Identifiant</label><input type="text" id="adminname" name="adminname" value="admin" /></li>
						<li><label for="adminpass">Mot de passe</label><input type="password" id="adminpass" name="adminpass" value="" /></li>
						<li><label for="adminpass2">Retapez le mot de passe</label><input type="password" id="adminpass2" name="adminpass2" value="" /></li>
					</ul>
				</fieldset>
				<fieldset>
					<legend>APO</legend>
					<ul>
						<li><label for="apourl">URL du site</label><input type="text" id="apourl" name="apourl" value="http://localhost/apo" /></li>
					</ul>
				</fieldset>
				<p>
					<input type="submit" name="submit" value="Installer" />
				</p>
			</form>
			<?php }else if($stopInstall){ ?>
			<p>Erreur lors de l'installation.</p>
			<ul><?php echo $success.$errors; ?></ul>
			<?php }else{ ?>
			<p>Installation réussie.</p>
			<ul><?php echo $success.$errors; ?></ul>
			<?php } ?>
		</div>
	</body>
</html>
